summaryrefslogtreecommitdiff
path: root/src/mongo/dbtests/config_server_fixture.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/dbtests/config_server_fixture.h')
-rw-r--r--src/mongo/dbtests/config_server_fixture.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/dbtests/config_server_fixture.h b/src/mongo/dbtests/config_server_fixture.h
index 9aa33e612eb..55c2d7f559f 100644
--- a/src/mongo/dbtests/config_server_fixture.h
+++ b/src/mongo/dbtests/config_server_fixture.h
@@ -73,7 +73,7 @@ namespace mongo {
class CustomConnectHook: public ConnectionString::ConnectionHook {
public:
virtual DBClientBase* connect(const ConnectionString& connStr,
- string& errmsg,
+ std::string& errmsg,
double socketTimeout)
{
// Note - must be new, since it gets owned elsewhere
@@ -98,10 +98,10 @@ namespace mongo {
}
/**
* Returns a connection string to the virtual config server.
*/
ConnectionString configSvr() const {
- return ConnectionString(string("$dummy:10000"));
+ return ConnectionString(std::string("$dummy:10000"));
}
/**
@@ -98,10 +98,10 @@ namespace mongo {
}
/**
- * Returns a connection string to the virtual config server.
+ * Returns a connection std::string to the virtual config server.
*/
ConnectionString configSvr() const {